@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 def importVarious(context):
     """
     Import various settings for collective.contacts
@@ -19,4 +20,14 @@ def importVarious(context):
                       'traverse_to',
                       'string:more_edit')
     return "Added validator and action for the 'more' button to " \
-           "the form controller."
\ No newline at end of file
+           "the form controller."
+
+def reindexCatalog(context):
+    """
+    This method will reindex the 2 new indexes added to the catalog
+    """
+    from Products.CMFCore.utils import getToolByName
+    site = context.getSite()
+    cat = getToolByName(site, 'portal_catalog')
+    cat.reindexIndex('lastName', site.REQUEST)
+    cat.reindexIndex('firstName', site.REQUEST)
